@@ -11,6 +11,7 @@ from .fields import (
     BooleanField,
     DateTimeField,
     DecimalField,
+    DictField,
     EmbeddedField,
     FieldParamters,
     FloatField,
@@ -34,6 +35,7 @@ __all__ = [
     "BooleanField",
     "DateTimeField",
     "DecimalField",
+    "DictField",
     "EmbeddedField",
     "FieldParamters",
     "FloatField",
